@@ -1,6 +1,6 @@
 /* _NVRM_COPYRIGHT_BEGIN_
  *
- * Copyright 2001-2011 by NVIDIA Corporation.  All rights reserved.  All
+ * Copyright 2001-2013 by NVIDIA Corporation.  All rights reserved.  All
  * information contained herein is proprietary and confidential to NVIDIA
  * Corporation.  Any use, reproduction, or disclosure without the written
  * permission of NVIDIA Corporation is prohibited.
@@ -21,11 +21,8 @@
 
 #include <sys/param.h>
 
-#if __FreeBSD_version >= 1200000
-#error This driver does not support FreeBSD 12.x/-CURRENT!
-#endif
-#if __FreeBSD_version >= 1100000 && __FreeBSD_version < 1100122
-#error This driver requires FreeBSD 11.0 or later!
+#if __FreeBSD_version >= 1100000
+#error This driver does not support FreeBSD 11.x/-CURRENT!
 #endif
 #if __FreeBSD_version >= 1000000 && __FreeBSD_version < 1000510
 #error This driver requires FreeBSD 10.0 or later!
@@ -87,13 +84,6 @@
 #include <vm/vm_pager.h>
 #include <vm/uma.h>
 
-#if __FreeBSD_version < 800004
-#include <pci/agpvar.h>
-#else
-#include <dev/agp/agpvar.h>
-#endif
-#include <sys/agpio.h>
-
 #include <sys/smp.h>
 #include <dev/pci/pcireg.h>
 #include <dev/pci/pcivar.h>
@@ -133,14 +123,6 @@
 
 MALLOC_DECLARE(M_NVIDIA);
 
-/*
- * Enable/Disable support for FreeBSD's AGP GART driver. Please note that
- * agp.ko may need to be preloaded from loader.conf; this define does not
- * influence support for NVIDIA's builtin AGP GART driver.
- */
-
-#undef NV_SUPPORT_OS_AGP
-
 /*
  * This option decides if the driver will be built with support for Linux
  * or Linux 32-bit (FreeBSD/amd64) compatibility. This makes nvidia.ko
@@ -150,6 +132,17 @@ MALLOC_DECLARE(M_NVIDIA);
 
 #define NV_SUPPORT_LINUX_COMPAT
 
+/*
+ * Enable/Disable support for ACPI method (_DOD, _ROM, etc.) invocation
+ * from the core driver.
+ */
+
+#if __FreeBSD_version >= 900044
+#define NV_SUPPORT_ACPI
+#else
+#undef NV_SUPPORT_ACPI
+#endif
+
 /*
  * Enable/Disable support for ACPI Power Management.
  */
@@ -164,13 +157,6 @@ MALLOC_DECLARE(M_NVIDIA);
 
 #undef NV_USE_WBINVD
 
-/*
- * The DMA memory allocation tracking structure. DMA memory alloctions on
- * FreeBSD are tracked with their base address and size. Since PCI memory
- * is allocated from kernel virtual memory and since AGP allocations have
- * a contiguous range of addresses in the AGP aperture, base and size are
- * sufficient to track allocations.
- */
 typedef
 struct nvidia_pte {
     vm_offset_t virtual_address;
@@ -198,6 +184,7 @@ typedef
 struct nvidia_filep {
     nv_state_t *nv;
     STAILQ_HEAD(event_queue, nvidia_event) event_queue;
+    int event_pending;
     struct mtx event_mtx;
     struct selinfo event_rsel;
 } nvidia_filep_t;
@@ -211,10 +198,6 @@ struct nvidia_work {
 typedef
 struct nvidia_softc {
     device_t dev;
-    device_t agp_dev;
-
-    struct sglist *AGP_sg_list;
-    vm_object_t AGP_object;
 
     struct sglist *UD_sg_list;
     vm_object_t UD_object;
@@ -344,7 +327,8 @@ NvU8   nvidia_pci_find_capability     (device_t dev, NvU8);
 #define NV_PCI_CHECK_CONFIG_SPACE(sp,nv,cb,as,mb)                       \
     {                                                                   \
         struct nvidia_softc *__sc;                                      \
-        if (((nv)->flags & NV_FLAG_CONTROL) == 0) {                     \
+        if ((((nv)->flags & NV_FLAG_CONTROL) == 0) &&                   \
+            (((nv)->flags & NV_FLAG_SKIP_CFG_CHECK) == 0)) {            \
             __sc = (nv)->os_state;                                      \
             nvidia_pci_check_config_space(sp, __sc->dev, cb, as, mb);   \
         }                                                               \
@@ -370,11 +354,6 @@ NvS32  nv_free_contig_pages  (nv_state_t *, void *);
 NvS32  nv_alloc_system_pages (nv_state_t *, NvU32, NvU32, NvBool, NvU64 *, void **);
 NvS32  nv_free_system_pages  (nv_state_t *, void *);
 
-NvS32  nv_os_agp_init        (nv_stack_t *sp, nv_state_t *, NvU64 *, NvU64 *);
-NvS32  nv_os_agp_teardown    (nv_stack_t *sp, nv_state_t *);
-NvS32  nv_alloc_agp_pages    (nv_state_t *, NvU32, NvU32, void **);
-NvS32  nv_free_agp_pages     (nv_state_t *, NvU32, void *, NvU32 *);
-
 #define NV_SGLIST_FREE(sgl)             \
     {                                   \
         sglist_free(sgl);               \
@@ -428,17 +407,6 @@ int    nvidia_sysctl_bus_type   (SYSCTL_HANDLER_ARGS);
 int    nvidia_sysctl_registry_key     (SYSCTL_HANDLER_ARGS);
 int    nvidia_sysctl_registry_dwords  (SYSCTL_HANDLER_ARGS);
 
-int    nvidia_sysctl_agp_rates      (SYSCTL_HANDLER_ARGS);
-int    nvidia_sysctl_agp_fw         (SYSCTL_HANDLER_ARGS);
-int    nvidia_sysctl_agp_sba        (SYSCTL_HANDLER_ARGS);
-int    nvidia_sysctl_agp_registers  (SYSCTL_HANDLER_ARGS);
-int    nvidia_sysctl_agp_driver     (SYSCTL_HANDLER_ARGS);
-
-int    nvidia_sysctl_agp_status       (SYSCTL_HANDLER_ARGS);
-int    nvidia_sysctl_agp_rate_status  (SYSCTL_HANDLER_ARGS);
-int    nvidia_sysctl_agp_fw_status    (SYSCTL_HANDLER_ARGS);
-int    nvidia_sysctl_agp_sba_status   (SYSCTL_HANDLER_ARGS);
-
 void   nv_sysctl_init        (nv_state_t *);
 void   nv_sysctl_exit        (nv_state_t *);
 
@@ -459,6 +427,9 @@ int    nvidia_open_ctl       (nv_state_t *, struct nvidia_filep *);
 int    nvidia_open_dev       (nv_state_t *, struct nvidia_filep *);
 int    nvidia_close_ctl      (nv_state_t *, struct nvidia_filep *);
 int    nvidia_close_dev      (nv_state_t *, struct nvidia_filep *);
-int    nvidia_mmap_dev_single(nv_state_t *, vm_ooffset_t *, vm_size_t, vm_object_t *);
+int    nvidia_mmap_ctl_single(nv_state_t *, struct nvidia_filep *, vm_ooffset_t *,
+        vm_size_t, vm_object_t *);
+int    nvidia_mmap_dev_single(nv_state_t *, struct nvidia_filep *, vm_ooffset_t *,
+        vm_size_t, vm_object_t *);
 
 #endif /* __NV_FREEBSD_H__ */
